@@ -18,9 +18,9 @@
 #'   files. If you really want to do so, set this to `TRUE`.
 #' @param compress Choose the type of compression used by [save()].
 #'   Should be one of "gzip", "bzip2", or "xz".
-#' @param version The serialization format version to use. The default, 2, was
-#'   the default format from R 1.4.0 to 3.5.3. Version 3 became the default from
-#'   R 3.6.0 and can only be read by R versions 3.5.0 and higher.
+#' @param version The serialization format version to use. The default, 3, can
+#'   only be read by R versions 3.5.0 and higher. For R 1.4.0 to 3.5.3, use
+#'   version 2.
 #' @inheritParams base::save
 #'
 #' @seealso The [data chapter](https://r-pkgs.org/data.html) of [R
@@ -38,17 +38,19 @@ use_data <- function(...,
                      internal = FALSE,
                      overwrite = FALSE,
                      compress = "bzip2",
-                     version = 2,
+                     version = 3,
                      ascii = FALSE) {
   check_is_package("use_data()")
 
   objs <- get_objs_from_dots(dots(...))
 
-  if (version < 3) {
-    use_dependency("R", "depends", "2.10")
-  } else {
-    use_dependency("R", "depends", "3.5")
+  original_minimum_r_version <- pkg_minimum_r_version()
+  serialization_minimum_r_version <- if (version < 3) "2.10" else "3.5"
+  if (is.na(original_minimum_r_version) ||
+      original_minimum_r_version < serialization_minimum_r_version) {
+        use_dependency("R", "depends", serialization_minimum_r_version)
   }
+
   if (internal) {
     use_directory("R")
     paths <- path("R", "sysdata.rda")
@@ -92,7 +94,7 @@ get_objs_from_dots <- function(.dots) {
   }
 
   is_name <- vapply(.dots, is.symbol, logical(1))
-  if (any(!is_name)) {
+  if (!all(is_name)) {
     ui_abort("Can only save existing named objects.")
   }
 
