@@ -26,28 +26,39 @@ create_directory <- function(path) {
   if (dir_exists(path)) {
     return(invisible(FALSE))
   } else if (file_exists(path)) {
-    ui_stop("{ui_path(path)} exists but is not a directory.")
+    ui_abort("{.path {pth(path)}} exists but is not a directory.")
   }
 
-  dir_create(path, recursive = TRUE)
-  ui_done("Creating {ui_path(path)}")
+  dir_create(path, recurse = TRUE)
+  ui_bullets(c("v" = "Creating {.path {pth(path)}}."))
   invisible(TRUE)
 }
 
 check_path_is_directory <- function(path) {
   if (!file_exists(path)) {
-    ui_stop("Directory {ui_path(path)} does not exist.")
+    ui_abort("Directory {.path {pth(path)}} does not exist.")
+  }
+
+  if (is_link(path)) {
+    path <- link_path(path)
   }
 
   if (!is_dir(path)) {
-    ui_stop("{ui_path(path)} is not a directory.")
+    ui_abort("{.path {pth(path)}} is not a directory.")
   }
 }
 
+count_directory_files <- function(x) {
+  length(dir_ls(x))
+}
+
+directory_has_files <- function(x) {
+  count_directory_files(x) >= 1
+}
+
 check_directory_is_empty <- function(x) {
-  files <- dir_ls(x)
-  if (length(files) > 0) {
-    ui_stop("{ui_path(x)} exists and is not an empty directory.")
+  if (directory_has_files(x)) {
+    ui_abort("{.path {pth(x)}} exists and is not an empty directory.")
   }
   invisible(x)
 }
