@@ -17,12 +17,12 @@
 use_spell_check <- function(vignettes = TRUE,
                             lang = "en-US",
                             error = FALSE) {
-  check_is_package("use_spell_check")
+  check_is_package("use_spell_check()")
   check_installed("spelling")
   use_dependency("spelling", "Suggests")
-  use_description_field("Language", lang, overwrite = TRUE)
+  proj_desc_field_update("Language", lang, overwrite = TRUE)
   spelling::spell_check_setup(
     pkg = proj_get(), vignettes = vignettes, lang = lang, error = error
   )
-  ui_todo("Run {ui_code('devtools::check()')} to trigger spell check")
+  ui_bullets(c("_" = "Run {.run devtools::check()} to trigger spell check."))
 }
