@@ -1,6 +1,3 @@
-## attempt to activate a project, which is nice during development
-tryCatch(proj_set("."), error = function(e) NULL)
-
 ## If session temp directory appears to be, or be within, a project, there
 ## will be large scale, spurious test failures.
 ## The IDE sometimes leaves .Rproj files behind in session temp directory or
@@ -9,10 +6,10 @@ tryCatch(proj_set("."), error = function(e) NULL)
 session_temp_proj <- proj_find(path_temp())
 if (!is.null(session_temp_proj)) {
   Rproj_files <- fs::dir_ls(session_temp_proj, glob = "*.Rproj")
-  ui_line(c(
-    "Rproj file(s) found at or above session temp dir:",
-    paste0("* ", Rproj_files),
-    "Expect this to cause spurious test failures."
+  ui_bullets(c(
+    "x" = "Rproj {cli::qty(length(Rproj_files))} file{?s} found at or above session temp dir:",
+    bulletize(usethis_map_cli(Rproj_files)),
+    "!" = "Expect this to cause spurious test failures."
   ))
 }
 
@@ -34,36 +31,59 @@ create_local_thing <- function(dir = file_temp(pattern = pattern),
                                thing = c("package", "project")) {
   thing <- match.arg(thing)
   if (fs::dir_exists(dir)) {
-    ui_stop("Target {ui_code('dir')} {ui_path(dir)} already exists.")
+    ui_abort("Target {.arg dir} {.path {pth(dir)}} already exists.")
   }
 
   old_project <- proj_get_() # this could be `NULL`, i.e. no active project
   old_wd <- getwd()          # not necessarily same as `old_project`
 
-  withr::defer(fs::dir_delete(dir), envir = env)
+  withr::defer(
+    {
+      ui_bullets(c("Deleting temporary project: {.path {dir}}"))
+      fs::dir_delete(dir)
+    },
+    envir = env
+  )
   ui_silence(
     switch(
       thing,
-      package = create_package(dir, rstudio = rstudio, open = FALSE, check_name = FALSE),
+      package = create_package(
+        dir,
+        # This is for the sake of interactive development of snapshot tests.
+        # When the active usethis project is a package created with this
+        # function, testthat learns its edition from *that* package, not from
+        # usethis. So, by default, opt in to testthat 3e in these ephemeral test
+        # packages.
+        fields = list("Config/testthat/edition" = "3"),
+        rstudio = rstudio,
+        open = FALSE,
+        check_name = FALSE
+      ),
       project = create_project(dir, rstudio = rstudio, open = FALSE)
     )
   )
 
-  withr::defer(setwd(old_wd), envir = env)
-  setwd(dir)
-
-  withr::defer(ui_silence(proj_set(old_project, force = TRUE)), envir = env)
+  withr::defer(proj_set(old_project, force = TRUE), envir = env)
   proj_set(dir)
 
-  invisible(dir)
+  withr::defer(
+    {
+      ui_bullets(c("Restoring original working directory: {.path {old_wd}}"))
+      setwd(old_wd)
+    },
+    envir = env
+  )
+  setwd(proj_get())
+
+  invisible(proj_get())
 }
 
-toggle_rlang_interactive <- function() {
-  before <- getOption("rlang_interactive")
-  after <- if (identical(before, FALSE)) TRUE else FALSE
-  options(rlang_interactive = after)
-  ui_line(glue::glue("rlang_interactive: {before %||% '<unset>'} --> {after}"))
-  invisible()
+scrub_testpkg <- function(message) {
+  gsub("testpkg[a-zA-Z0-9]+", "{TESTPKG}", message, perl = TRUE)
+}
+
+scrub_testproj <- function(message) {
+  gsub("testproj[a-zA-Z0-9]+", "{TESTPROJ}", message, perl = TRUE)
 }
 
 skip_if_not_ci <- function() {
@@ -76,9 +96,8 @@ skip_if_not_ci <- function() {
 }
 
 skip_if_no_git_user <- function() {
-  cfg <- git2r::config()
-  user_name <- cfg$local$`user.name` %||% cfg$global$`user.name`
-  user_email <- cfg$local$`user.email` %||% cfg$global$`user.email`
+  user_name <- git_cfg_get("user.name")
+  user_email <- git_cfg_get("user.email")
   user_name_exists <- !is.null(user_name)
   user_email_exists <- !is.null(user_email)
   if (user_name_exists && user_email_exists) {
@@ -88,7 +107,7 @@ skip_if_no_git_user <- function() {
 }
 
 # CRAN's mac builder sets $HOME to a read-only ram disk, so tests can fail if
-# you even tickle something that might try to lock it's own config file during
+# you even tickle something that might try to lock its own config file during
 # the operation (e.g. git) or if you simply test for writeability
 skip_on_cran_macos <- function() {
   sysname <- tolower(Sys.info()[["sysname"]])
@@ -103,10 +122,6 @@ expect_usethis_error <- function(...) {
   expect_error(..., class = "usethis_error")
 }
 
-expect_error_free <- function(...) {
-  expect_error(..., regexp = NA)
-}
-
 is_build_ignored <- function(pattern, ..., base_path = proj_get()) {
   lines <- read_utf8(path(base_path, ".Rbuildignore"))
   length(grep(pattern, x = lines, fixed = TRUE, ...)) > 0
